@@ -1,27 +1,28 @@
 from datetime import datetime
 from pathlib import Path
-from typing import Dict, List, Literal, Optional
+from typing import Dict, List, Optional
 
 from fastapi import APIRouter, Depends, Form, Query, Security
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import FileResponse, JSONResponse
 
-import statina
 from statina.adapter import StatinaAdapter
 from statina.API.v2.endpoints.user import get_current_active_user
 from statina.config import get_nipt_adapter
-from statina.constants import sample_sort_keys, sample_status_options
+from statina.constants import sample_status_options
 from statina.crud import update
-from statina.crud.find.plots.zscore_plot_data import (
-    get_abn_for_samp_tris_plot,
-    get_normal_for_samp_tris_plot,
-    get_sample_for_samp_tris_plot,
-)
-from statina.crud.find.samples import query_samples, count_query_samples
-
-from statina.models.database import DataBaseSample, User
+from statina.crud.find import samples as find_samples
+from statina.crud.find import batches as find_batches
+from statina.crud.find.plots import zscore_plot_data
+from statina.models.database import DataBaseSample, User, DatabaseBatch
+from statina.models.query_params import SamplesQuery
 from statina.models.server.plots.ncv import Zscore131821, ZscoreSamples
-from statina.models.server.sample import Sample, PaginatedSampleResponse
+from statina.models.server.sample import (
+    Sample,
+    PaginatedSampleResponse,
+    SampleValidator,
+)
+
 from statina.parse.batch import validate_file_path
 
 router = APIRouter(prefix="/v2")
@@ -29,33 +30,25 @@ router = APIRouter(prefix="/v2")
 
 @router.get("/samples", response_model=PaginatedSampleResponse)
 def samples(
-    batch_id: Optional[str] = Query(None),
-    page_size: Optional[int] = Query(5),
-    page_num: Optional[int] = Query(0),
-    sort_key: Optional[sample_sort_keys] = Query("sample_id"),
-    sort_direction: Optional[Literal["ascending", "descending"]] = Query("descending"),
-    query_string: Optional[str] = Query(""),
+    sample_query: SamplesQuery = Depends(SamplesQuery),
     current_user: User = Security(get_current_active_user, scopes=["R"]),
     adapter: StatinaAdapter = Depends(get_nipt_adapter),
 ):
     """Get samples"""
-    samples: List[DataBaseSample] = query_samples(
-        batch_id=batch_id,
-        adapter=adapter,
-        page_size=page_size,
-        page_num=page_num,
-        sort_key=sort_key,
-        sort_direction=sort_direction,
-        query_string=query_string,
+    database_samples: List[DataBaseSample] = find_samples.query_samples(
+        **sample_query.dict(), adapter=adapter
     )
-    validated_samples: List[Sample] = [Sample(**sample_obj.dict()) for sample_obj in samples]
-    document_count: int = count_query_samples(
-        adapter=adapter, batch_id=batch_id, query_string=query_string
+    validated_samples: List[SampleValidator] = [
+        SampleValidator(**sample.dict()) for sample in database_samples
+    ]
+    samples: List[Sample] = [Sample(**sample.dict()) for sample in validated_samples]
+
+    document_count: int = find_samples.count_query_samples(
+        adapter=adapter, batch_id=sample_query.batch_id, query_string=sample_query.query_string
     )
     return JSONResponse(
         content=jsonable_encoder(
-            PaginatedSampleResponse(document_count=document_count, documents=validated_samples),
-            by_alias=False,
+            PaginatedSampleResponse(document_count=document_count, documents=samples), by_alias=True
         )
     )
 
@@ -68,15 +61,22 @@ def sample(
 ):
     """Get sample with id"""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
-    if not sample:
+    database_sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
+    batch: DatabaseBatch = find_batches.batch(batch_id=database_sample.batch_id, adapter=adapter)
+
+    if not database_sample:
         return JSONResponse("Not found", status_code=404)
-    validated_sample: Sample = Sample(**sample.dict())
+
+    validated_sample = SampleValidator(**database_sample.dict())
+    sample_view_data = Sample(
+        sequencing_date=batch.SequencingDate,
+        **validated_sample.dict(exclude_none=True),
+    )
 
     return JSONResponse(
         content=jsonable_encoder(
-            validated_sample,
-            by_alias=False,
+            sample_view_data,
+            by_alias=True,
         )
     )
 
@@ -88,10 +88,14 @@ def sample_tris(
     adapter: StatinaAdapter = Depends(get_nipt_adapter),
 ):
     """Sample view with trisomi plot."""
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
-    abnormal_data: Dict[str, ZscoreSamples] = get_abn_for_samp_tris_plot(adapter=adapter)
-    normal_data: Zscore131821 = get_normal_for_samp_tris_plot(adapter=adapter)
-    sample_data: ZscoreSamples = get_sample_for_samp_tris_plot(sample)
+
+    database_sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
+    abnormal_data: Dict[str, ZscoreSamples] = zscore_plot_data.get_abn_for_samp_tris_plot(
+        adapter=adapter
+    )
+    normal_data: Zscore131821 = zscore_plot_data.get_normal_for_samp_tris_plot(adapter=adapter)
+    sample_data: ZscoreSamples = zscore_plot_data.get_sample_for_samp_tris_plot(database_sample)
+
     return JSONResponse(
         content=jsonable_encoder(
             dict(
@@ -104,7 +108,7 @@ def sample_tris(
     )
 
 
-@router.put("/sample/{sample_id}/status_13")
+@router.put("/sample/{sample_id}/status/13")
 async def set_sample_status_13(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -113,7 +117,7 @@ async def set_sample_status_13(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_13 = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_13 = f"{current_user.username} {time_stamp}"
@@ -121,7 +125,7 @@ async def set_sample_status_13(
     return JSONResponse(content="Sample field updated", status_code=200)
 
 
-@router.put("/sample/{sample_id}/status_18")
+@router.put("/sample/{sample_id}/status/18")
 async def set_sample_status_18(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -130,7 +134,7 @@ async def set_sample_status_18(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_18 = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_18 = f"{current_user.username} {time_stamp}"
@@ -138,7 +142,7 @@ async def set_sample_status_18(
     return JSONResponse(content="Sample field updated", status_code=200)
 
 
-@router.put("/sample/{sample_id}/status_21")
+@router.put("/sample/{sample_id}/status/21")
 async def set_sample_status_21(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -147,7 +151,7 @@ async def set_sample_status_21(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_21 = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_21 = f"{current_user.username} {time_stamp}"
@@ -155,7 +159,7 @@ async def set_sample_status_21(
     return JSONResponse(content="Sample field updated", status_code=200)
 
 
-@router.put("/sample/{sample_id}/status_X0")
+@router.put("/sample/{sample_id}/status/x0")
 async def set_sample_status_x0(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -164,7 +168,7 @@ async def set_sample_status_x0(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_X0 = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_X0 = f"{current_user.username} {time_stamp}"
@@ -172,7 +176,7 @@ async def set_sample_status_x0(
     return JSONResponse(content="Sample field updated", status_code=200)
 
 
-@router.put("/sample/{sample_id}/status_XXY")
+@router.put("/sample/{sample_id}/status/xxy")
 async def set_sample_status_xxy(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -181,7 +185,7 @@ async def set_sample_status_xxy(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_XXY = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_XXY = f"{current_user.username} {time_stamp}"
@@ -189,7 +193,7 @@ async def set_sample_status_xxy(
     return JSONResponse(content="Sample field updated", status_code=200)
 
 
-@router.put("/sample/{sample_id}/status_XXX")
+@router.put("/sample/{sample_id}/status/xxx")
 async def set_sample_status_xxx(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -198,7 +202,7 @@ async def set_sample_status_xxx(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_XXX = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_XXX = f"{current_user.username} {time_stamp}"
@@ -206,7 +210,7 @@ async def set_sample_status_xxx(
     return JSONResponse(content="Sample field updated", status_code=200)
 
 
-@router.put("/sample/{sample_id}/status_XYY")
+@router.put("/sample/{sample_id}/status/xyy")
 async def set_sample_status_xyy(
     sample_id: str,
     status: sample_status_options = Query(...),
@@ -215,7 +219,7 @@ async def set_sample_status_xyy(
 ):
     """Update the manualy interpreted chromosome abnormality status for a sample."""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.status_XYY = status
     time_stamp: str = datetime.now().strftime("%Y/%m/%d %H:%M:%S")
     sample.status_change_XYY = f"{current_user.username} {time_stamp}"
@@ -232,7 +236,7 @@ async def sample_comment(
 ):
     """Update sample comment"""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.comment = comment
     update.sample(adapter=adapter, sample=sample)
 
@@ -248,7 +252,7 @@ async def sample_include(
 ):
     """Include sample in plots"""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(sample_id=sample_id, adapter=adapter)
+    sample: DataBaseSample = find_samples.sample(sample_id=sample_id, adapter=adapter)
     sample.include = include
     update.sample(adapter=adapter, sample=sample)
 
@@ -263,7 +267,7 @@ def sample_segmental_calls_download(
 ):
     """View for sample downloads"""
 
-    sample: DataBaseSample = statina.crud.find.samples.sample(adapter=adapter, sample_id=sample_id)
+    sample: DataBaseSample = find_samples.sample(adapter=adapter, sample_id=sample_id)
     file_path = sample.dict().get("segmental_calls")
     if not validate_file_path(file_path):
         # warn file missing!
